==> haskell-keys-3.12.3-309-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 keys
version:              3.12.3
visibility:           public
id:                   keys-3.12.3-7cabNTpgJLp1WyjKND3irD
key:                  keys-3.12.3-7cabNTpgJLp1WyjKND3irD
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/keys/
synopsis:             Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.

    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.

category:             Data Structures, Containers
abi:                  29ff4007f558c51066ccf1cbae494ea3
exposed:              True
exposed-modules:      Data.Key
import-dirs:          /usr/lib/ghc-9.2.8/site-local/keys-3.12.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/keys-3.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-keys
hs-libraries:         HSkeys-3.12.3-7cabNTpgJLp1WyjKND3irD
depends:
    array-0.5.4.0 base-4.16.4.0 comonad-5.0.8-KyyLY8sZRYu3prGxjDqPYp
    containers-0.6.5.1 free-5.1.10-AN4bUDGIWGDJVoND3kN9wg
    hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt
    semigroupoids-5.3.7-1YYAPqLiz5I2tSx9QdPdOI
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-3nVNqHdmWG59aZRDnxmFox

haddock-interfaces:   /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html:         /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-keys-3.12.3-318-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 keys
version:              3.12.3
visibility:           public
id:                   keys-3.12.3-XAbVJVpJP7FwA4kPD4byG
key:                  keys-3.12.3-XAbVJVpJP7FwA4kPD4byG
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/keys/
synopsis:             Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.

    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.

category:             Data Structures, Containers
abi:                  245524da0fb8cfbae66956cbe79f33ff
exposed:              True
exposed-modules:      Data.Key
import-dirs:          /usr/lib/ghc-9.2.8/site-local/keys-3.12.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/keys-3.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-keys
hs-libraries:         HSkeys-3.12.3-XAbVJVpJP7FwA4kPD4byG
depends:
    array-0.5.4.0 base-4.16.4.0 comonad-5.0.8-CZGmUOvuZnLIadrIFOwLfh
    containers-0.6.5.1 free-5.1.10-InRordVHVEk5oREFazAoui
    hashable-1.4.4.0-DtL5AH6y1if92iaAq0qoKj
    semigroupoids-5.3.7-Aol4v1yb5Zg1lc2q2bwPkl
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-KbuohGKDXjMH23185MHhrF

haddock-interfaces:   /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html:         /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
